package net.knarcraft.knargui;

import org.bukkit.entity.Player;
import org.bukkit.event.inventory.InventoryType;
import org.bukkit.inventory.AnvilInventory;

import java.util.function.BiConsumer;

/**
 * A user-interface using an anvil GUI
 */
@SuppressWarnings("unused")
public abstract class AnvilGUI extends AbstractGUI {

    private BiConsumer<String, Player> action;

    public AnvilGUI(String inventoryName) {
        super(0, inventoryName, InventoryType.ANVIL);
    }

    /**
     * Gets the text the user has written in the renaming field
     *
     * @return <p>The text in the renaming field</p>
     */
    public String getText() {
        AnvilInventory anvilInventory = (AnvilInventory) this.getInventory();
        return anvilInventory.getRenameText();
    }

    /**
     * Sets an action to be run if this GUI is closed
     *
     * <p>The action will be passed the current value of the anvil text</p>
     *
     * @param action <p>The action to be run</p>
     */
    public void setCloseAction(BiConsumer<String, Player> action) {
        this.action = action;
    }

    /**
     * Runs the action this GUI should run when closing
     *
     * @param player <p>The player that closed this GUI</p>
     */
    public void runCloseAction(Player player) {
        if (action != null) {
            this.action.accept(getText(), player);
        }
    }

}
